#[repr(C)]pub struct Sound {
pub stream: AudioStream,
pub frameCount: u32,
}Fields
stream: AudioStreamframeCount: u32Trait Implementations
sourceimpl SoundExt for Sound
impl SoundExt for Sound
sourcefn load_from_wave(wave: Wave) -> Sound
fn load_from_wave(wave: Wave) -> Sound
Load sound from wave data
sourcefn alias(self) -> Sound
fn alias(self) -> Sound
Create a new sound that shares the same sample data as the source sound, does not own the sound data
sourcefn unload_alias(self)
fn unload_alias(self)
Unload a sound alias (does not deallocate sample data)
sourcefn is_playing(self) -> bool
fn is_playing(self) -> bool
Check whether a sound is currently playing
sourcefn set_volume(self, volume: f32)
fn set_volume(self, volume: f32)
Set volume for a sound (1.0 is max level)
impl Copy for Sound